
```
0.2.0
🔧 changed money type to decimal
🎉 SBM.process_csv
🎉 SBM.csv_money_in
🎉 SBM.csv_money_out
📑 docs

0.1.1
🔧 Fix meta tags

0.1.0

🎉 MCB.process_csv
🎉 MCB.csv_money_in
🎉 MCB.csv_money_out
📑 docs
```
